Shafaq-Siddiqi opened a new pull request #1556:
URL: https://github.com/apache/systemds/pull/1556
- This commit changes the outer for loop of bandit::run_with_hyperparam to
parfor
alongside with previous improvements i.e. winsorizeApply, this commit
brings down
the execution time on EEG dataset from 14000 sec to 2200 sec.
- This commit also simplifies the sampling function inside utils.dml
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: [email protected]
For queries about this service, please contact Infrastructure at:
[email protected]